@@ -5,9 +5,10 @@ import pyglinet.exceptions as exceptions
 def login_required(func):
     @wraps(func)
     def inner_func(self, *args, **kwargs):
-        if not has_sid(self):
+        if _has_sid(self) and _is_alive(self):
+            return func(self, *args, **kwargs)
+        else:
             raise exceptions.NotLoggedInError(f"Login is required to execute function {func}.\nCall login() first!")
-        return func(self, *args, **kwargs)
 
     return inner_func
 
@@ -16,8 +17,8 @@ def logout_required(func):
     @wraps(func)
     def inner_func(self, *args, **kwargs):
         try:
-            if self.is_alive():
-                raise exceptions.LoggedInError("Logout before calling login again.")
+            if _is_alive(self):
+                raise exceptions.LoggedInError(f"Logout before calling function {func}")
         except exceptions.NotLoggedInError:
             pass
 
@@ -26,7 +27,7 @@ def logout_required(func):
     return inner_func
 
 
-def has_sid(func):
+def _has_sid(func):
     try:
         if func._sid is None:
             return False
@@ -34,3 +35,10 @@ def has_sid(func):
         if func._session._sid is None:
             return False
     return True
+
+
+def _is_alive(func):
+    try:
+        return func.is_alive()
+    except AttributeError:
+        return func._session.is_alive()
